/*
Copyright © 2023 Philipp Wolfer <phw@uploadedlobster.com>

This file is part of Scotty.

Scotty is free software: you can redistribute it and/or modify it under the
terms of the GNU General Public License as published by the Free Software
Foundation, either version 3 of the License, or (at your option) any later version.

Scotty is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
A PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with
Scotty. If not, see <https://www.gnu.org/licenses/>.
*/
package cmd

import (
	"fmt"
	"strings"

	"github.com/spf13/cobra"
	"go.uploadedlobster.com/scotty/internal/backends"
	"go.uploadedlobster.com/scotty/internal/i18n"
)

var backendsCmd = &cobra.Command{
	Use:   "backends",
	Short: "List available backends",
	Long:  `List the names and supported capabilities of all available backends.`,
	Run: func(cmd *cobra.Command, args []string) {
		backends := backends.GetBackends()
		for _, info := range backends {
			fmt.Printf("%s:\n", info.Name)
			fmt.Println(i18n.Tr("\texport: %s", strings.Join(info.ExportCapabilities, ", ")))
			fmt.Println(i18n.Tr("\timport: %s\n", strings.Join(info.ImportCapabilities, ", ")))
		}
	},
}

func init() {
	rootCmd.AddCommand(backendsCmd)

	// Here you will define your flags and configuration settings.

	// Cobra supports Persistent Flags which will work for this command
	// and all subcommands, e.g.:
	// backendsCmd.PersistentFlags().String("foo", "", "A help for foo")

	// Cobra supports local flags which will only run when this command
	// is called directly, e.g.:
	// backendsCmd.Flags().BoolP("toggle", "t", false, "Help message for toggle")
}
