/*
Copyright © 2023 Philipp Wolfer <phw@uploadedlobster.com>

This file is part of Scotty.

Scotty is free software: you can redistribute it and/or modify it under the
terms of the GNU General Public License as published by the Free Software
Foundation, either version 3 of the License, or (at your option) any later version.

Scotty is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
A PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with
Scotty. If not, see <https://www.gnu.org/licenses/>.
*/
package cmd

import (
	"github.com/spf13/cobra"
	"go.uploadedlobster.com/scotty/internal/backends"
	"go.uploadedlobster.com/scotty/internal/cli"
	"go.uploadedlobster.com/scotty/internal/config"
	"go.uploadedlobster.com/scotty/internal/models"
	"go.uploadedlobster.com/scotty/internal/storage"
)

var beamListensCmd = &cobra.Command{
	Use:        "listens SOURCE TARGET",
	Short:      "Transfer listens between two services",
	Long:       `Transfers listens between two configured services.`,
	Args:       cobra.ExactArgs(2),
	ArgAliases: []string{"source", "target"},
	Run: func(cmd *cobra.Command, args []string) {
		db, err := storage.New(config.DatabasePath())
		cobra.CheckErr(err)
		c, err := cli.NewTransferCmd[
			models.ListensExport,
			models.ListensImport,
			models.ListensResult,
		](cmd, &db, "listens", args[0], args[1])
		cobra.CheckErr(err)
		exp := backends.ListensExportProcessor{Backend: c.ExpBackend}
		imp := backends.ListensImportProcessor{Backend: c.ImpBackend}
		err = c.Transfer(exp, imp)
		cobra.CheckErr(err)
	},
}

func init() {
	beamCmd.AddCommand(beamListensCmd)
	// Here you will define your flags and configuration settings.

	// Cobra supports Persistent Flags which will work for this command
	// and all subcommands, e.g.:
	// beamListensCmd.PersistentFlags().String("foo", "", "A help for foo")

	// Cobra supports local flags which will only run when this command
	// is called directly, e.g.:
	// beamListensCmd.Flags().BoolP("toggle", "t", false, "Help message for toggle")
	beamListensCmd.Flags().StringP("timestamp", "t", "", "only import listens newer then given timestamp")
}
