/*
Copyright © 2023 Philipp Wolfer <phw@uploadedlobster.com>

This file is part of Scotty.

Scotty is free software: you can redistribute it and/or modify it under the
terms of the GNU General Public License as published by the Free Software
Foundation, either version 3 of the License, or (at your option) any later version.

Scotty is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
A PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with
Scotty. If not, see <https://www.gnu.org/licenses/>.
*/
package cmd

import (
	"github.com/spf13/cobra"
	"go.uploadedlobster.com/scotty/internal/auth"
	"go.uploadedlobster.com/scotty/internal/backends"
	"go.uploadedlobster.com/scotty/internal/cli"
)

var serviceAuthCmd = &cobra.Command{
	Use:   "auth",
	Short: "Authenticate a service",
	Long: `For backends requiring authentication this command can be used to authenticate.

Authentication is always done per configured service. That means you can have
multiple services using the same backend but different authentication.`,
	Run: func(cmd *cobra.Command, args []string) {
		serviceConfig, err := cli.SelectService(cmd)
		cobra.CheckErr(err)
		backend, err := backends.ResolveBackend[auth.OAuth2Authenticator](serviceConfig)
		cobra.CheckErr(err)
		cli.AuthenticationFlow(serviceConfig, backend)
	},
}

func init() {
	serviceCmd.AddCommand(serviceAuthCmd)
	serviceAuthCmd.Flags().StringP("service", "s", "", "service configuration")
}
