/*
Copyright © 2023 Philipp Wolfer <phw@uploadedlobster.com>

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
*/
package cmd

import (
	"fmt"

	"github.com/spf13/cobra"
	"go.uploadedlobster.com/scotty/internal/cli"
	"go.uploadedlobster.com/scotty/internal/i18n"
)

var serviceEditCmd = &cobra.Command{
	Use:   "edit",
	Short: "Edit existing service configuration",
	Long:  `Edit an existing service in the configuration file.`,
	Run: func(cmd *cobra.Command, args []string) {
		service, err := cli.SelectService(cmd)
		cobra.CheckErr(err)

		// Select backend
		backend, err := cli.SelectBackend(service.Backend)
		cobra.CheckErr(err)
		service.Backend = backend

		// Additional options
		service, err = cli.PromptExtraOptions(service)
		cobra.CheckErr(err)

		// Save the service config
		err = service.Save()
		cobra.CheckErr(err)
		fmt.Println(i18n.Tr("Updated service %v using backend %v\n", service.Name, service.Backend))
	},
}

func init() {
	serviceCmd.AddCommand(serviceEditCmd)
	serviceEditCmd.Flags().StringP("service", "s", "", "service configuration")
}
