/*
Copyright © 2023 Philipp Wolfer <phw@uploadedlobster.com>

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
*/

// Package for reading and writing music playlists in the JSPF format.
//
// JSPF is the JSON representation of XSPF, see https://www.xspf.org/jspf
package jspf

import (
	"encoding/json"
	"io"
)

// Reads the JSPF playlist in JSON format from the given io.Reader
func (j *JSPF) Read(in io.Reader) error {
	bytes, err := io.ReadAll(in)
	if err != nil {
		return err
	}
	err = json.Unmarshal(bytes, j)
	return err
}

// Writes the JSPF playlist in JSON format to the given io.Writer
func (j *JSPF) Write(out io.Writer) error {
	jspfJson, err := json.MarshalIndent(j, "", "\t")
	if err != nil {
		return err
	}

	_, err = out.Write(jspfJson)
	return err
}
