/*
Copyright © 2023 Philipp Wolfer <phw@uploadedlobster.com>

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
*/

package jspf_test

import (
	"bytes"
	"fmt"
	"log"
	"os"
	"time"

	"go.uploadedlobster.com/scotty/pkg/jspf"
)

func ExampleJSPF_Read() {
	file, err := os.Open("testdata/simple.jspf")
	if err != nil {
		log.Fatal(err)
	}

	defer file.Close()

	pl := jspf.JSPF{}
	err = pl.Read(file)
	if err != nil {
		log.Fatal(err)
	}
	fmt.Printf("Playlist '%v' with %v tracks",
		pl.Playlist.Title, len(pl.Playlist.Tracks))
	// Output: Playlist 'Two Songs From Thriller' with 2 tracks
}

func ExampleJSPF_Write() {
	date, _ := time.Parse(time.RFC3339, "2023-11-23T23:56:00Z")
	pl := jspf.JSPF{
		Playlist: jspf.Playlist{
			Title:   "The Playlist",
			Creator: "Scotty",
			Date:    date,
			Tracks: []jspf.Track{
				{
					Title: "The Track",
				},
			},
		},
	}
	buf := bytes.NewBuffer(make([]byte, 0, 10))
	err := pl.Write(buf)
	if err != nil {
		log.Fatal(err)
	}
	fmt.Print(buf.String())
	// Output:
	// {
	// 	"playlist": {
	// 		"title": "The Playlist",
	// 		"creator": "Scotty",
	// 		"date": "2023-11-23T23:56:00Z",
	// 		"track": [
	// 			{
	// 				"title": "The Track"
	// 			}
	// 		]
	// 	}
	// }
}
