/*
Copyright © 2023-2025 Philipp Wolfer <phw@uploadedlobster.com>

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
*/

package jspf

import "time"

// A JSPF playlist
//
// See https://xspf.org/jspf
type JSPF struct {
	Playlist Playlist `json:"playlist"`
}

type Playlist struct {
	Title       string        `json:"title,omitempty"`
	Creator     string        `json:"creator,omitempty"`
	Annotation  string        `json:"annotation,omitempty"`
	Info        string        `json:"info,omitempty"`
	Location    string        `json:"location,omitempty"`
	Identifier  string        `json:"identifier,omitempty"`
	Image       string        `json:"image,omitempty"`
	Date        time.Time     `json:"date,omitempty"`
	License     string        `json:"license,omitempty"`
	Attribution []Attribution `json:"attribution,omitempty"`
	Links       []Link        `json:"link,omitempty"`
	Meta        []Meta        `json:"meta,omitempty"`
	Extension   ExtensionMap  `json:"extension,omitempty"`
	Tracks      []Track       `json:"track"`
}

type Track struct {
	Location   []string     `json:"location,omitempty"`
	Identifier []string     `json:"identifier,omitempty"`
	Title      string       `json:"title,omitempty"`
	Creator    string       `json:"creator,omitempty"`
	Annotation string       `json:"annotation,omitempty"`
	Info       string       `json:"info,omitempty"`
	Album      string       `json:"album,omitempty"`
	TrackNum   int          `json:"trackNum,omitempty"`
	Duration   int64        `json:"duration,omitempty"`
	Links      []Link       `json:"link,omitempty"`
	Meta       []Meta       `json:"meta,omitempty"`
	Extension  ExtensionMap `json:"extension,omitempty"`
}

type Attribution map[string]string

type Link map[string]string

type Meta map[string]string
